#
# spec file for package seergdb
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global optflags %{?optflags} -fpie
%global build_ldflags %{?build_ldflags} -pie

%if 0%{?suse_version} && 0%{?suse_version} < 1550
%global force_gcc_version 12
%endif

Name:           seergdb
Version:        2.5
Release:        1.2
Summary:        A GUI front-end for GNU gdb
License:        GPL-3.0-or-later
Group:          Development/Tools/Debuggers
URL:            https://github.com/epasveer/seer
Source0:        %{url}/archive/refs/tags/v%{version}.tar.gz#/seergdb-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  gcc%{?force_gcc_version}
BuildRequires:  gcc%{?force_gcc_version}-c++
BuildRequires:  qt6-base-devel
BuildRequires:  qt6-charts-devel
BuildRequires:  qt6-svg-devel
Requires:       gdb
Recommends:     libQt6Svg6

%description
A GUI front-end for GNU gdb written in modern C++.

%prep
%setup -q -n seer-%{version}

%build
%if 0%{?force_gcc_version}
export CC="gcc-%{?force_gcc_version}"
export CXX="g++-%{?force_gcc_version}"
%endif
cd src
%cmake
%cmake_build

%install
mkdir -p %{buildroot}/%{_bindir}
install -m 0755 src/build/%{name} %{buildroot}/%{_bindir}/%{name}

mkdir -p %{buildroot}%{_datadir}/applications
install -m 0644 src/resources/%{name}.desktop %{buildroot}/%{_datadir}/applications/%{name}.desktop

mkdir -p %{buildroot}%{_datadir}/icons/hicolor/32x32/apps
install -m 0644 src/resources/%{name}_32x32.png %{buildroot}%{_datadir}/icons/hicolor/32x32/apps/%{name}.png

mkdir -p %{buildroot}%{_datadir}/icons/hicolor/64x64/apps
install -m 0644 src/resources/%{name}_64x64.png %{buildroot}%{_datadir}/icons/hicolor/64x64/apps/%{name}.png

mkdir -p %{buildroot}%{_datadir}/icons/hicolor/128x128/apps
install -m 0644 src/resources/%{name}_128x128.png %{buildroot}%{_datadir}/icons/hicolor/128x128/apps/%{name}.png

mkdir -p %{buildroot}%{_datadir}/icons/hicolor/256x256/apps
install -m 0644 src/resources/%{name}_256x256.png %{buildroot}%{_datadir}/icons/hicolor/256x256/apps/%{name}.png

mkdir -p %{buildroot}%{_datadir}/icons/hicolor/512x512/apps
install -m 0644 src/resources/%{name}_512x512.png %{buildroot}%{_datadir}/icons/hicolor/512x512/apps/%{name}.png

%files
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor

%changelog
* Tue Mar  4 2025 Martin Schreiner <martin.schreiner@suse.com>
  * Upgrade to v2.5.
  * Console now supports a subset of ANSI color codes.
  * Console can be started in these modes:
  - Detached
  - Detached and minimized
  - Attached in Seer's tab view (with gdb logs and seer logs).
  * Improved handling of \n \t and other escaped characters in gdb log window.
  * Show breakpoint info as a tooltip if the breakpoint icon is clicked with
  * LMB and held down.
  * Show stack as a hex dump, with options to view as short, int, long, ascii, ...
  * The "go to address" in the Assembly view now works if address it outside
  current assembly view.
  * Visualizers can take a gdb expression for input fields for
  length/size of something. The visualizers are:
  - ArrayVisualizer
  - ImageVisualizer
  - MemoryVisualizer
  * Fixed regression when setting/saving the editor font setting.
  * Fixed bug when the Basic Struct visualizer display simple variable
  types (non-structs).
  * Source all files in ~/.config/seergdb/scripts/ on startup.
  * Fixed regression handling ignoring of system header files.
  * Fixed regression when adding commands to a breakpoint.
  * Refactored/improved Printpoints. Added 'help' to the
  * Printpoint create dialog.
  * Fixed regression when display variable value when hovering over
  the text in the editor window.
* Mon Jul 29 2024 Martin Schreiner <martin.schreiner@suse.com>
- Enable position-independent executables.
- Use CMake macros.
- Improve GCC-related conditionals.
* Wed May 22 2024 Martin Schreiner <martin.schreiner@suse.com>
- Upgrade to v2.4:
  * Changed main icon to a more license friendly one.
  * All icons are now GPLv3, CC3.0, or CC4.0
  * Fixed string compares for breakpoint conditions
  * Added '--bs' command line option to specify a breakpoint at a
    source.cpp:lineno
  * Fixed long tooltips text by restricting them to 100 characters.
  * The text in the various viewing dialogs is still the full length.
  * The 100 limit probably needs to be configurable.
  * Added register profiles to show only interesting/relevant registers.
  * Added UTF-8,16,32 support in the Memory Visualizer.
  * Added an internal "dark" and "light" theme via the View->Style menu.
  * Added option to open the current source file in an external editor.
  * Fixed saving of RR parameters in config dialog.
  * Sped up some visualization views.
* Sat Sep 23 2023 Martin Schreiner <martin.schreiner@suse.com>
- Upgrade to v2.2:
  * Small RR release. Seer now runs 'rr replay' internally.
  * Fixed infinite loop when starting with RR mode.
  * Reworked RR mode to directly run 'rr replay'.
    No need to start a 'rr server' and connect to it.
  * Fixed Source handling in source browser.
    Qt5 mode was broken.
    Qt6 works. Directory paths need a tailing "/*".
- Fix build for openSUSE 15.5.
  Changed from the default gcc version (7) to gcc 12, since it
  supports C++17.
- Remove doubly declared files in the spec, removing some warnings.
- Add missing "Group" information.
* Sat Aug 26 2023 Martin Schreiner <martin.schreiner@suse.com>
- Add a missing "Recommends" entry for qt6-svg.
* Wed Aug 23 2023 Martin Schreiner <martin.schreiner@suse.com>
- Upgrade to v2.1:
  * Add Execution dialog to record breakpoint events. This solves the
    problem of too many break/error dialogs to "swat away" as the
    program is debugged.
  * Add a method to add/change gdb commands to execute when a
    breakpoint (breakpoint, watchpoint, catchpoint) is reached.
  * Add a method to add/change a breakpoint's condition command.
  * Add a method to add/change a breakpoint's ignore count.
  * Add a method to add/change a breakpoint's command list.
  * Debug dialog for "attach" mode now detects executable name and
    path from /proc//exe.
  * Commandline for "attach" mode now detects executable name and path
    from /proc//exe.
* Mon Aug  7 2023 Martin Schreiner <martin.schreiner@suse.com>
- Initial submission for v2.0.
